==> open-cluster-management-agent-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigListFluent.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KlusterletAddonConfigListFluent<A extends KlusterletAddonConfigListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,KlusterletAddonConfig item);
  public A setToItems(Integer index,KlusterletAddonConfig item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items);
  public A addAllToItems(Collection<KlusterletAddonConfig> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items);
  public A removeAllFromItems(Collection<KlusterletAddonConfig> items);
  public A removeMatchingFromItems(Predicate<KlusterletAddonConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KlusterletAddonConfig> getItems();
  public List<KlusterletAddonConfig> buildItems();
  public KlusterletAddonConfig buildItem(Integer index);
  public KlusterletAddonConfig buildFirstItem();
  public KlusterletAddonConfig buildLastItem();
  public KlusterletAddonConfig buildMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate);
  public A withItems(List<KlusterletAddonConfig> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items);
  public Boolean hasItems();
  public KlusterletAddonConfigListFluent.ItemsNested<A> addNewItem();
  public KlusterletAddonConfigListFluent.ItemsNested<A> addNewItemLike(KlusterletAddonConfig item);
  public KlusterletAddonConfigListFluent.ItemsNested<A> setNewItemLike(Integer index,KlusterletAddonConfig item);
  public KlusterletAddonConfigListFluent.ItemsNested<A> editItem(Integer index);
  public KlusterletAddonConfigListFluent.ItemsNested<A> editFirstItem();
  public KlusterletAddonConfigListFluent.ItemsNested<A> editLastItem();
  public KlusterletAddonConfigListFluent.ItemsNested<A> editMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KlusterletAddonConfigFluent<KlusterletAddonConfigListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-agent-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigListFluent.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KlusterletAddonConfigListFluent<A extends KlusterletAddonConfigListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,KlusterletAddonConfig item);
  public A setToItems(int index,KlusterletAddonConfig item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items);
  public A addAllToItems(Collection<KlusterletAddonConfig> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items);
  public A removeAllFromItems(Collection<KlusterletAddonConfig> items);
  public A removeMatchingFromItems(Predicate<KlusterletAddonConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KlusterletAddonConfig> getItems();
  public List<KlusterletAddonConfig> buildItems();
  public KlusterletAddonConfig buildItem(int index);
  public KlusterletAddonConfig buildFirstItem();
  public KlusterletAddonConfig buildLastItem();
  public KlusterletAddonConfig buildMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate);
  public A withItems(List<KlusterletAddonConfig> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.agent.v1.KlusterletAddonConfig... items);
  public Boolean hasItems();
  public KlusterletAddonConfigListFluent.ItemsNested<A> addNewItem();
  public KlusterletAddonConfigListFluent.ItemsNested<A> addNewItemLike(KlusterletAddonConfig item);
  public KlusterletAddonConfigListFluent.ItemsNested<A> setNewItemLike(int index,KlusterletAddonConfig item);
  public KlusterletAddonConfigListFluent.ItemsNested<A> editItem(int index);
  public KlusterletAddonConfigListFluent.ItemsNested<A> editFirstItem();
  public KlusterletAddonConfigListFluent.ItemsNested<A> editLastItem();
  public KlusterletAddonConfigListFluent.ItemsNested<A> editMatchingItem(Predicate<KlusterletAddonConfigBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KlusterletAddonConfigFluent<KlusterletAddonConfigListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
